/*
 * Copyright 2005 Red Hat, Inc.
 */
#include "../config.h"
#include <sys/types.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include "common.h"
#include "oddjob_dbus.h"
#define EXPECTED_ERROR "org.freedesktop.DBus.Error.ServiceUnknown"

#ident "$Id: oddjob_request.c,v 1.1 2005/04/25 18:58:27 nalin Exp $"

int
main(int argc, char **argv)
{
	int i;
	char buf[8192];
	const char *usage = "Usage: oddjob_request [request "
			    "[arg1 [arg2 [arg3 [arg4]]]]]";

	/* If we got any options, assume that the user doesn't know how to call
	 * the program. */
	for (i = 1; i < argc; i++) {
		if (argv[i][0] == '-') {
			printf("%s\n", usage);
			exit(1);
		}
	}

	/* If we got no arguments, assume that they need help on using the
	 * program. */
	if (argc == 1) {
		printf("%s\n", usage);
	}

	/* Send the request as the user requested.  If they specified no
	 * request, then run the "list" method. */
	i = oddjob_dbus_call_method(ODDJOB_SERVICE_NAME,
				    ODDJOB_OBJECT_PATH,
				    ODDJOB_INTERFACE_NAME,
				    argc > 1 ? argv[1] : "list",
				    buf, sizeof(buf),
				    argc > 2 ? argv[2] : NULL,
				    argc > 3 ? argv[3] : NULL,
				    argc > 4 ? argv[4] : NULL,
				    argc > 5 ? argv[5] : NULL);

	if (i == 0) {
		/* If we ran the "list" method, and we got a response string,
		 * display it to the user. */
		if (argc <= 1) {
			if (strlen(buf) > 0) {
				printf("Recognized requests: %s\n", buf);
			}
		} else {
			/* Otherwise, if we got a result of any kind, display
			 * it to the user. */
			if (strlen(buf) > 0) {
				printf("%s\n", buf);
			}
		}
	} else {
		if (strlen(buf) > 0) {
			if (strncmp(buf, EXPECTED_ERROR,
				    strlen(EXPECTED_ERROR)) != 0) {
				fprintf(stderr, "%s\n", buf);
			}
		}
	}

	return i;
}
